@@ -21,7 +21,15 @@ from livestyled.schemas.location import LocationSchema
 from livestyled.schemas.magic_field import MagicFieldSchema
 from livestyled.schemas.news import NewsSchema
 from livestyled.schemas.order import OrderSchema
-from livestyled.schemas.payment import MerchantAccountSchema, PaymentCustomerSchema, PaymentGatewaySchema, PaymentIntentSchema, PaymentSourceSchema
+from livestyled.schemas.payment import (
+    MerchantAccountFulfilmentPointPspTokenSchema,
+    MerchantAccountFulfilmentPointSchema,
+    MerchantAccountSchema,
+    PaymentCustomerSchema,
+    PaymentGatewaySchema,
+    PaymentIntentSchema,
+    PaymentSourceSchema
+)
 from livestyled.schemas.product import (
     ProductCategorySchema,
     ProductModifierItemSchema,
@@ -35,6 +43,7 @@ from livestyled.schemas.push_consent import PushConsentSchema
 from livestyled.schemas.reality import RealitySchema, RealityTypeSchema
 from livestyled.schemas.season import SeasonSchema
 from livestyled.schemas.sport_venue import SportVenueSchema
+from livestyled.schemas.storage import ExportSchema
 from livestyled.schemas.team import TeamSchema
 from livestyled.schemas.ticket import TicketSchema
 from livestyled.schemas.ticket_auth import TicketAuthSchema
@@ -60,6 +69,7 @@ __all__ = [
     EventCategorySchema,
     EventIntegrationSchema,
     EventStageSchema,
+    ExportSchema,
     FixtureSchema,
     FulfilmentPointSchema,
     LeagueTableSchema,
@@ -67,6 +77,8 @@ __all__ = [
     LocationSchema,
     MagicFieldSchema,
     MerchantAccountSchema,
+    MerchantAccountFulfilmentPointSchema,
+    MerchantAccountFulfilmentPointPspTokenSchema,
     NewsSchema,
     OrderSchema,
     PaymentCustomerSchema,
